︠28ae7c11-9a41-4ab9-be9d-9efb4877ab3ai︠
%html
<p>Adapting a <a title="sage-devel post" href="https://groups.google.com/group/sage-devel/msg/e53caae140cef7df" target="_blank">useful trick</a>, we attempt to set up analogues of IPython's "magic" <span style="font-family: andale mono,times;"><a title="%timeit IPython documentation" href="http://ipython.scipy.org/doc/manual/html/api/generated/IPython.Magic.html#IPython.Magic.Magic.magic_timeit" target="_blank">%timeit</a></span> function for notebook cells.&nbsp; See <span style="font-family: andale mono,times;"><a title="Python timeit module documentation" href="http://docs.python.org/library/timeit.html" target="_blank">timeit</a></span> for documentation on the underlying Python library module.</p>
<p>First, we wrap an existing Sage library function:</p>

︡d4b280a7-8ca7-4765-884b-bc80983b124d︡{"html": "<p>Adapting a <a title=\"sage-devel post\" href=\"https://groups.google.com/group/sage-devel/msg/e53caae140cef7df\" target=\"_blank\">useful trick</a>, we attempt to set up analogues of IPython's \"magic\" <span style=\"font-family: andale mono,times;\"><a title=\"%timeit IPython documentation\" href=\"http://ipython.scipy.org/doc/manual/html/api/generated/IPython.Magic.html#IPython.Magic.Magic.magic_timeit\" target=\"_blank\">%timeit</a></span> function for notebook cells.&nbsp; See <span style=\"font-family: andale mono,times;\"><a title=\"Python timeit module documentation\" href=\"http://docs.python.org/library/timeit.html\" target=\"_blank\">timeit</a></span> for documentation on the underlying Python library module.</p>\n<p>First, we wrap an existing Sage library function:</p>"}︡
︠9fcffb84-bdd9-4675-aa81-77246eafaeae︠
class timeit1:
    def __init__(self, number=0, repeat=3, precision=3, preparse=False):
        self.number = number
        self.repeat = repeat
        self.precision = precision
        self.preparse = preparse
    def eval(self, s, globals, locals):
        return sage.misc.sage_timeit.sage_timeit(s, globals, number=self.number, repeat=self.repeat, precision=self.precision, preparse=self.preparse)
︡631da45d-0bed-4166-839c-4ff2966a44e1︡︡
︠70e51560-12cc-4bdc-b78e-742e3bcceae7︠
%timeit1()
c = (1 + 1j) / 3
z = 0
for i in xrange(100):
    z = z**2 + c
︡659977e7-06c3-48f3-82d5-02b01b47e4fd︡{"stdout": "625 loops, best of 3: 16.9 \u00b5s per loop"}︡
︠7acd8bea-e780-4346-a913-9bad8bc4a254︠
import time
︡6f0dbe84-a4f5-42a7-b165-590b83b5af41︡︡
︠80b1b2ca-6da3-41c8-9ebb-a4a7dd6b5bce︠
%timeit1(number=1)
print 'Sleeping...'
time.sleep(1)
print 'Awake!'
︡51191662-40ba-4a98-8578-7b9862a20b86︡{"stdout": "1 loops, best of 3: 996 ms per loop"}︡
︠e83086b9-2f3e-4e7c-9862-2ae961bf2d30i︠
%html
<p>Here's an alternative, with sample statistics computed for <span style="font-family: andale mono,times;">repeat</span> iterations:</p>

︡41c3c56b-fc45-4631-acf8-ad0e48533f86︡{"html": "<p>Here's an alternative, with sample statistics computed for <span style=\"font-family: andale mono,times;\">repeat</span> iterations:</p>"}︡
︠84fb24e0-8e9b-4ac9-8db1-c233b673c797︠
class timeit2:
    def __init__(self, repeat=1, precision=3, preparse=True):
        import time
        self.time = time.time
        self.repeat = repeat
        self.precision = int(precision)
        self.preparse = preparse
    def eval(self, s, globals, locals):
        if self.preparse:
            s = preparse(s)
        results = []
        for r in xrange(self.repeat):
            start_time = self.time()
            ans = python.eval(s,  globals, locals)
            results.append(self.time() - start_time)
        v = vector(RDF, results)
        print 'r = %d, mean = %.*g, std. dev. = %.*g' % (self.repeat, self.precision, v.mean(), self.precision, v.standard_deviation(population=True))
        return ans
︡1a77871e-28b4-4fbf-81c2-788b4bfddd81︡︡
︠09de7a87-563d-4113-8b95-da0fff6de36a︠
def iterate(f, n, x):
    ans = x
    for i in xrange(n):
        ans = f(ans)
    return ans
︡3427be7f-3c32-41b9-aeac-bca2f79f00dd︡︡
︠df206f37-5161-4e9e-88d1-5e9a37474c94︠
%timeit2(repeat=10)
big = iterate(lambda x: x ^ x, 2, 8)
︡050ae510-2c7b-4b60-a748-c8ba95a4ef71︡{"stdout": "r = 10, mean = 0.108, std. dev. = 0.0175"}︡
︠aac871e3-0836-49dc-80c9-73cafe2c1c10︠
%timeit2(repeat=3, precision=5)
print 'Sleeping...'
time.sleep(1)
print 'Awake!'
︡5f43e450-982f-418e-ab80-e485121d7825︡{"stdout": "Sleeping...\nAwake!\nSleeping...\nAwake!\nSleeping...\nAwake!\nr = 3, mean = 0.99736, std. dev. = 0.0049723"}︡
